elephant.test.test_unitary_event_analysis module — Elephant 0.5.0 documentation

# elephant.test.test_unitary_event_analysis module

Unit tests for the Unitary Events analysis

class `elephant.test.test_unitary_event_analysis.` `UETestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  static `load_gdf2Neo`(fname, trigger, t_pre, t_post)

    load and convert the gdf file to Neo format by cutting and aligning around a given trigger # codes for trigger events (extracted from a # documentation of an old file after # contacting Dr. Alexa Rihle) # 700 : ST (correct) 701, 702, 703, 704* # 500 : ST (error =5) 501, 502, 503, 504* # 1000: ST (if no selec) 1001,1002,1003,1004* # 11 : PS 111, 112, 113, 114 # 12 : RS 121, 122, 123, 124 # 13 : RT 131, 132, 133, 134 # 14 : MT 141, 142, 143, 144 # 15 : ES 151, 152, 153, 154 # 16 : ES 161, 162, 163, 164 # 17 : ES 171, 172, 173, 174 # 19 : RW 191, 192, 193, 194 # 20 : ET 201, 202, 203, 204

  `setUp`()
  `test_Riehle_et_al_97_UE`()
  `test__UE_default`()
  `test__UE_surrogate`()
  `test__bintime`()
  `test__rate_mat_avg_trial_default`()
  `test__winpos`()
  `test_gen_pval_anal_default`()
  `test_hash_ValueError_wrong_entries`()
  `test_hash_ValueError_wrong_orientation`()
  `test_hash_base_not_two`()
  `test_hash_default`()
  `test_hash_default_longpattern`()
  `test_hash_invhash_consistency`()
  `test_invhash_ValueError`()
  `test_invhash_base_not_two`()
  `test_invhash_default_base`()
  `test_invhash_shape_mat`()
  `test_jointJ_default`()
  `test_jointJ_window_analysis`()
  `test_n_emp_mat_default`()
  `test_n_emp_mat_sum_trial_ValueError`()
  `test_n_emp_mat_sum_trial_default`()
  `test_n_exp_mat_default`()
  `test_n_exp_mat_sum_trial_TrialAverage`()
  `test_n_exp_mat_sum_trial_ValueError`()
  `test_n_exp_mat_sum_trial_default`()
  `test_n_exp_mat_sum_trial_surrogate`()

`elephant.test.test_unitary_event_analysis.` `suite`()